@@ -21,7 +21,7 @@ require Exporter;
     @SRC_IPS whois_config
 );
 
-$VERSION = '0.95';
+$VERSION = '0.99';
 
 ($OMIT_MSG, $CHECK_FAIL, $CHECK_EXCEED, $CACHE_DIR, $USE_CNAMES, $TIMEOUT) = (0) x 6;
 $CACHE_TIME = 1;
@@ -308,6 +308,9 @@ sub whois_query {
     if ($srv eq 'whois.melbourneit.com' && $israce) {
         $whoisquery .= ' race';
     }
+    if ($srv eq 'whois.denic.de') {
+        $whoisquery = "-T dn,ace -C ISO-8859-1 $whoisquery";
+    }
     #warn "$srv: $whoisquery ($OMIT_MSG, $CHECK_FAIL, $CACHE_DIR, $CACHE_TIME, $USE_CNAMES, $TIMEOUT)\n";
     print $sock "$whoisquery\r\n";
     my @lines = <$sock>;
@@ -451,7 +454,7 @@ Net::Whois::Raw - Get Whois information for domains
 =head1 DESCRIPTION
 
 Net::Whois::Raw queries WHOIS servers about domains.
-The module supportts recursive WHOIS queries.
+The module supports recursive WHOIS queries.
 
 Setting the variables $OMIT_MSG and $CHECK_FAIL will match the results
 against a set of known patterns. The first flag will try to omit the
